# coding: utf-8

"""
    IN10T Client Data API

    IN10T Client Data API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: matt@in10t.ag
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import in10t_api_client
from in10t_api_client.api.trials_api import TrialsApi  # noqa: E501
from in10t_api_client.rest import ApiException


class TestTrialsApi(unittest.TestCase):
    """TrialsApi unit test stubs"""

    def setUp(self):
        self.api = in10t_api_client.api.trials_api.TrialsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_trial_list(self):
        """Test case for trial_list

        View a list of active trials.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
