# coding: utf-8

"""
    IN10T Client Data API

    IN10T Client Data API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: matt@in10t.ag
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import in10t_api_client
from in10t_api_client.models.access_token import AccessToken  # noqa: E501
from in10t_api_client.rest import ApiException


class TestAccessToken(unittest.TestCase):
    """AccessToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAccessToken(self):
        """Test AccessToken"""
        # FIXME: construct object with mandatory attributes with example values
        # model = in10t_api_client.models.access_token.AccessToken()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
